IMap2D_tests {#master}
-----------

Important Changes
-----------------

### Libraries

#### `harness_dev`
* MapGrid2DTest.cpp refactored
* Added tests for `Map2DClient -> Map2DServer` communication
* Added tests for `Map2D_nwc_yarp -> Map2D_nws_yarp` communication

